from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.TColgp import *
from OCC.Core.SelectMgr import *
from OCC.Core.Quantity import *
from OCC.Core.Select3D import *
from OCC.Core.gp import *
from OCC.Core.TColStd import *
from OCC.Core.Bnd import *
from OCC.Core.TCollection import *
from OCC.Core.Graphic3d import *
from OCC.Core.SelectBasics import *
from OCC.Core.AIS import *
from OCC.Core.PrsMgr import *
from OCC.Core.Prs3d import *
from OCC.Core.Aspect import *

MeshVS_BuilderPriority = NewType('MeshVS_BuilderPriority', Standard_Integer)
MeshVS_ColorHasher = NewType('MeshVS_ColorHasher', Quantity_ColorHasher)
MeshVS_DisplayModeFlags = NewType('MeshVS_DisplayModeFlags', Standard_Integer)
#the following typedef cannot be wrapped as is
MeshVS_MapIteratorOfMapOfTwoNodes = NewType('MeshVS_MapIteratorOfMapOfTwoNodes', Any)
#the following typedef cannot be wrapped as is
MeshVS_MapOfTwoNodes = NewType('MeshVS_MapOfTwoNodes', Any)
MeshVS_MeshPtr = NewType('MeshVS_MeshPtr', MeshVS_Mesh)
#the following typedef cannot be wrapped as is
MeshVS_NodePair = NewType('MeshVS_NodePair', Any)
#the following typedef cannot be wrapped as is
MeshVS_TwoColorsHasher = NewType('MeshVS_TwoColorsHasher', Any)
#the following typedef cannot be wrapped as is
MeshVS_TwoNodesHasher = NewType('MeshVS_TwoNodesHasher', Any)

class MeshVS_Array1OfSequenceOfInteger:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> TColStd_SequenceOfInteger: ...
    def __setitem__(self, index: int, value: TColStd_SequenceOfInteger) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[TColStd_SequenceOfInteger]: ...
    def next(self) -> TColStd_SequenceOfInteger: ...
    __next__ = next
    def Init(self, theValue: TColStd_SequenceOfInteger) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> TColStd_SequenceOfInteger: ...
    def Last(self) -> TColStd_SequenceOfInteger: ...
    def Value(self, theIndex: int) -> TColStd_SequenceOfInteger: ...
    def SetValue(self, theIndex: int, theValue: TColStd_SequenceOfInteger) -> None: ...

class MeshVS_PolyhedronVerts:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Append(self, theItem: False) -> False: ...
    def Prepend(self, theItem: False) -> False: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class MeshVS_SequenceOfPrsBuilder:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Length(self) -> int: ...
    def Append(self, theItem: False) -> False: ...
    def Prepend(self, theItem: False) -> False: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class MeshVS_EntityType(IntEnum):
	MeshVS_ET_NONE: int = ...
	MeshVS_ET_Node: int = ...
	MeshVS_ET_0D: int = ...
	MeshVS_ET_Link: int = ...
	MeshVS_ET_Face: int = ...
	MeshVS_ET_Volume: int = ...
	MeshVS_ET_Element: int = ...
	MeshVS_ET_All: int = ...
MeshVS_ET_NONE = MeshVS_EntityType.MeshVS_ET_NONE
MeshVS_ET_Node = MeshVS_EntityType.MeshVS_ET_Node
MeshVS_ET_0D = MeshVS_EntityType.MeshVS_ET_0D
MeshVS_ET_Link = MeshVS_EntityType.MeshVS_ET_Link
MeshVS_ET_Face = MeshVS_EntityType.MeshVS_ET_Face
MeshVS_ET_Volume = MeshVS_EntityType.MeshVS_ET_Volume
MeshVS_ET_Element = MeshVS_EntityType.MeshVS_ET_Element
MeshVS_ET_All = MeshVS_EntityType.MeshVS_ET_All

class MeshVS_MeshSelectionMethod(IntEnum):
	MeshVS_MSM_PRECISE: int = ...
	MeshVS_MSM_NODES: int = ...
	MeshVS_MSM_BOX: int = ...
MeshVS_MSM_PRECISE = MeshVS_MeshSelectionMethod.MeshVS_MSM_PRECISE
MeshVS_MSM_NODES = MeshVS_MeshSelectionMethod.MeshVS_MSM_NODES
MeshVS_MSM_BOX = MeshVS_MeshSelectionMethod.MeshVS_MSM_BOX

class MeshVS_SelectionModeFlags(IntEnum):
	MeshVS_SMF_Mesh: int = ...
	MeshVS_SMF_Node: int = ...
	MeshVS_SMF_0D: int = ...
	MeshVS_SMF_Link: int = ...
	MeshVS_SMF_Face: int = ...
	MeshVS_SMF_Volume: int = ...
	MeshVS_SMF_Element: int = ...
	MeshVS_SMF_All: int = ...
	MeshVS_SMF_Group: int = ...
MeshVS_SMF_Mesh = MeshVS_SelectionModeFlags.MeshVS_SMF_Mesh
MeshVS_SMF_Node = MeshVS_SelectionModeFlags.MeshVS_SMF_Node
MeshVS_SMF_0D = MeshVS_SelectionModeFlags.MeshVS_SMF_0D
MeshVS_SMF_Link = MeshVS_SelectionModeFlags.MeshVS_SMF_Link
MeshVS_SMF_Face = MeshVS_SelectionModeFlags.MeshVS_SMF_Face
MeshVS_SMF_Volume = MeshVS_SelectionModeFlags.MeshVS_SMF_Volume
MeshVS_SMF_Element = MeshVS_SelectionModeFlags.MeshVS_SMF_Element
MeshVS_SMF_All = MeshVS_SelectionModeFlags.MeshVS_SMF_All
MeshVS_SMF_Group = MeshVS_SelectionModeFlags.MeshVS_SMF_Group

class MeshVS_DrawerAttribute(IntEnum):
	MeshVS_DA_InteriorStyle: int = ...
	MeshVS_DA_InteriorColor: int = ...
	MeshVS_DA_BackInteriorColor: int = ...
	MeshVS_DA_EdgeColor: int = ...
	MeshVS_DA_EdgeType: int = ...
	MeshVS_DA_EdgeWidth: int = ...
	MeshVS_DA_HatchStyle: int = ...
	MeshVS_DA_FrontMaterial: int = ...
	MeshVS_DA_BackMaterial: int = ...
	MeshVS_DA_BeamType: int = ...
	MeshVS_DA_BeamWidth: int = ...
	MeshVS_DA_BeamColor: int = ...
	MeshVS_DA_MarkerType: int = ...
	MeshVS_DA_MarkerColor: int = ...
	MeshVS_DA_MarkerScale: int = ...
	MeshVS_DA_TextColor: int = ...
	MeshVS_DA_TextHeight: int = ...
	MeshVS_DA_TextFont: int = ...
	MeshVS_DA_TextExpansionFactor: int = ...
	MeshVS_DA_TextSpace: int = ...
	MeshVS_DA_TextStyle: int = ...
	MeshVS_DA_TextDisplayType: int = ...
	MeshVS_DA_TextTexFont: int = ...
	MeshVS_DA_TextFontAspect: int = ...
	MeshVS_DA_VectorColor: int = ...
	MeshVS_DA_VectorMaxLength: int = ...
	MeshVS_DA_VectorArrowPart: int = ...
	MeshVS_DA_IsAllowOverlapped: int = ...
	MeshVS_DA_Reflection: int = ...
	MeshVS_DA_ColorReflection: int = ...
	MeshVS_DA_ShrinkCoeff: int = ...
	MeshVS_DA_MaxFaceNodes: int = ...
	MeshVS_DA_ComputeTime: int = ...
	MeshVS_DA_ComputeSelectionTime: int = ...
	MeshVS_DA_DisplayNodes: int = ...
	MeshVS_DA_SelectableAuto: int = ...
	MeshVS_DA_ShowEdges: int = ...
	MeshVS_DA_SmoothShading: int = ...
	MeshVS_DA_SupressBackFaces: int = ...
	MeshVS_DA_User: int = ...
MeshVS_DA_InteriorStyle = MeshVS_DrawerAttribute.MeshVS_DA_InteriorStyle
MeshVS_DA_InteriorColor = MeshVS_DrawerAttribute.MeshVS_DA_InteriorColor
MeshVS_DA_BackInteriorColor = MeshVS_DrawerAttribute.MeshVS_DA_BackInteriorColor
MeshVS_DA_EdgeColor = MeshVS_DrawerAttribute.MeshVS_DA_EdgeColor
MeshVS_DA_EdgeType = MeshVS_DrawerAttribute.MeshVS_DA_EdgeType
MeshVS_DA_EdgeWidth = MeshVS_DrawerAttribute.MeshVS_DA_EdgeWidth
MeshVS_DA_HatchStyle = MeshVS_DrawerAttribute.MeshVS_DA_HatchStyle
MeshVS_DA_FrontMaterial = MeshVS_DrawerAttribute.MeshVS_DA_FrontMaterial
MeshVS_DA_BackMaterial = MeshVS_DrawerAttribute.MeshVS_DA_BackMaterial
MeshVS_DA_BeamType = MeshVS_DrawerAttribute.MeshVS_DA_BeamType
MeshVS_DA_BeamWidth = MeshVS_DrawerAttribute.MeshVS_DA_BeamWidth
MeshVS_DA_BeamColor = MeshVS_DrawerAttribute.MeshVS_DA_BeamColor
MeshVS_DA_MarkerType = MeshVS_DrawerAttribute.MeshVS_DA_MarkerType
MeshVS_DA_MarkerColor = MeshVS_DrawerAttribute.MeshVS_DA_MarkerColor
MeshVS_DA_MarkerScale = MeshVS_DrawerAttribute.MeshVS_DA_MarkerScale
MeshVS_DA_TextColor = MeshVS_DrawerAttribute.MeshVS_DA_TextColor
MeshVS_DA_TextHeight = MeshVS_DrawerAttribute.MeshVS_DA_TextHeight
MeshVS_DA_TextFont = MeshVS_DrawerAttribute.MeshVS_DA_TextFont
MeshVS_DA_TextExpansionFactor = MeshVS_DrawerAttribute.MeshVS_DA_TextExpansionFactor
MeshVS_DA_TextSpace = MeshVS_DrawerAttribute.MeshVS_DA_TextSpace
MeshVS_DA_TextStyle = MeshVS_DrawerAttribute.MeshVS_DA_TextStyle
MeshVS_DA_TextDisplayType = MeshVS_DrawerAttribute.MeshVS_DA_TextDisplayType
MeshVS_DA_TextTexFont = MeshVS_DrawerAttribute.MeshVS_DA_TextTexFont
MeshVS_DA_TextFontAspect = MeshVS_DrawerAttribute.MeshVS_DA_TextFontAspect
MeshVS_DA_VectorColor = MeshVS_DrawerAttribute.MeshVS_DA_VectorColor
MeshVS_DA_VectorMaxLength = MeshVS_DrawerAttribute.MeshVS_DA_VectorMaxLength
MeshVS_DA_VectorArrowPart = MeshVS_DrawerAttribute.MeshVS_DA_VectorArrowPart
MeshVS_DA_IsAllowOverlapped = MeshVS_DrawerAttribute.MeshVS_DA_IsAllowOverlapped
MeshVS_DA_Reflection = MeshVS_DrawerAttribute.MeshVS_DA_Reflection
MeshVS_DA_ColorReflection = MeshVS_DrawerAttribute.MeshVS_DA_ColorReflection
MeshVS_DA_ShrinkCoeff = MeshVS_DrawerAttribute.MeshVS_DA_ShrinkCoeff
MeshVS_DA_MaxFaceNodes = MeshVS_DrawerAttribute.MeshVS_DA_MaxFaceNodes
MeshVS_DA_ComputeTime = MeshVS_DrawerAttribute.MeshVS_DA_ComputeTime
MeshVS_DA_ComputeSelectionTime = MeshVS_DrawerAttribute.MeshVS_DA_ComputeSelectionTime
MeshVS_DA_DisplayNodes = MeshVS_DrawerAttribute.MeshVS_DA_DisplayNodes
MeshVS_DA_SelectableAuto = MeshVS_DrawerAttribute.MeshVS_DA_SelectableAuto
MeshVS_DA_ShowEdges = MeshVS_DrawerAttribute.MeshVS_DA_ShowEdges
MeshVS_DA_SmoothShading = MeshVS_DrawerAttribute.MeshVS_DA_SmoothShading
MeshVS_DA_SupressBackFaces = MeshVS_DrawerAttribute.MeshVS_DA_SupressBackFaces
MeshVS_DA_User = MeshVS_DrawerAttribute.MeshVS_DA_User

class MeshVS_Buffer:
	@overload
	def __init__(self, theSize: int) -> None: ...

class MeshVS_CommonSensitiveEntity(Select3D_SensitiveSet):
	def __init__(self, theOwner: SelectMgr_EntityOwner, theParentMesh: MeshVS_Mesh, theSelMethod: MeshVS_MeshSelectionMethod) -> None: ...
	def BoundingBox(self) -> Select3D_BndBox3d: ...
	def Box(self, theIdx: int) -> Select3D_BndBox3d: ...
	def Center(self, theIdx: int, theAxis: int) -> float: ...
	def CenterOfGeometry(self) -> gp_Pnt: ...
	def GetConnected(self) -> Select3D_SensitiveEntity: ...
	def NbSubElements(self) -> int: ...
	def Size(self) -> int: ...
	def Swap(self, theIdx1: int, theIdx2: int) -> None: ...

class MeshVS_DataSource(Standard_Transient):
	def Get3DGeom(self, ID: int, Data: MeshVS_HArray1OfSequenceOfInteger) -> Tuple[bool, int]: ...
	def GetAddr(self, ID: int, IsElement: bool) -> None: ...
	def GetAllElements(self) -> TColStd_PackedMapOfInteger: ...
	def GetAllGroups(self, Ids: TColStd_PackedMapOfInteger) -> None: ...
	def GetAllNodes(self) -> TColStd_PackedMapOfInteger: ...
	def GetBoundingBox(self) -> Bnd_Box: ...
	@overload
	def GetDetectedEntities(self, Prs: MeshVS_Mesh, X: float, Y: float, aTol: float, Nodes: TColStd_HPackedMapOfInteger, Elements: TColStd_HPackedMapOfInteger) -> Tuple[bool, float]: ...
	@overload
	def GetDetectedEntities(self, Prs: MeshVS_Mesh, XMin: float, YMin: float, XMax: float, YMax: float, aTol: float, Nodes: TColStd_HPackedMapOfInteger, Elements: TColStd_HPackedMapOfInteger) -> bool: ...
	@overload
	def GetDetectedEntities(self, Prs: MeshVS_Mesh, Polyline: TColgp_Array1OfPnt2d, aBox: Bnd_Box2d, aTol: float, Nodes: TColStd_HPackedMapOfInteger, Elements: TColStd_HPackedMapOfInteger) -> bool: ...
	@overload
	def GetDetectedEntities(self, Prs: MeshVS_Mesh, Nodes: TColStd_HPackedMapOfInteger, Elements: TColStd_HPackedMapOfInteger) -> bool: ...
	def GetGeom(self, ID: int, IsElement: bool, Coords: TColStd_Array1OfReal, Type: MeshVS_EntityType) -> Tuple[bool, int]: ...
	def GetGeomType(self, ID: int, IsElement: bool, Type: MeshVS_EntityType) -> bool: ...
	def GetGroup(self, Id: int, Type: MeshVS_EntityType, Ids: TColStd_PackedMapOfInteger) -> bool: ...
	def GetGroupAddr(self, ID: int) -> None: ...
	def GetNodeNormal(self, ranknode: int, ElementId: int) -> Tuple[bool, float, float, float]: ...
	def GetNodesByElement(self, ID: int, NodeIDs: TColStd_Array1OfInteger) -> Tuple[bool, int]: ...
	def GetNormal(self, Id: int, Max: int) -> Tuple[bool, float, float, float]: ...
	def GetNormalsByElement(self, Id: int, IsNodal: bool, MaxNodes: int, Normals: TColStd_HArray1OfReal) -> bool: ...
	def IsAdvancedSelectionEnabled(self) -> bool: ...

class MeshVS_Drawer(Standard_Transient):
	def Assign(self, aDrawer: MeshVS_Drawer) -> None: ...
	def GetAsciiString(self, Key: int, Value: TCollection_AsciiString) -> bool: ...
	def GetBoolean(self, Key: int) -> Tuple[bool, bool]: ...
	def GetColor(self, Key: int, Value: Quantity_Color) -> bool: ...
	def GetDouble(self, Key: int) -> Tuple[bool, float]: ...
	def GetInteger(self, Key: int) -> Tuple[bool, int]: ...
	def GetMaterial(self, Key: int, Value: Graphic3d_MaterialAspect) -> bool: ...
	def RemoveAsciiString(self, Key: int) -> bool: ...
	def RemoveBoolean(self, Key: int) -> bool: ...
	def RemoveColor(self, Key: int) -> bool: ...
	def RemoveDouble(self, Key: int) -> bool: ...
	def RemoveInteger(self, Key: int) -> bool: ...
	def RemoveMaterial(self, Key: int) -> bool: ...
	def SetAsciiString(self, Key: int, Value: TCollection_AsciiString) -> None: ...
	def SetBoolean(self, Key: int, Value: bool) -> None: ...
	def SetColor(self, Key: int, Value: Quantity_Color) -> None: ...
	def SetDouble(self, Key: int, Value: float) -> None: ...
	def SetInteger(self, Key: int, Value: int) -> None: ...
	def SetMaterial(self, Key: int, Value: Graphic3d_MaterialAspect) -> None: ...

class MeshVS_DummySensitiveEntity(Select3D_SensitiveEntity):
	def __init__(self, theOwnerId: SelectMgr_EntityOwner) -> None: ...
	def BVH(self) -> None: ...
	def BoundingBox(self) -> Select3D_BndBox3d: ...
	def CenterOfGeometry(self) -> gp_Pnt: ...
	def Clear(self) -> None: ...
	def HasInitLocation(self) -> bool: ...
	def InvInitLocation(self) -> gp_GTrsf: ...
	def Matches(self, theMgr: SelectBasics_SelectingVolumeManager, thePickResult: SelectBasics_PickResult) -> bool: ...
	def NbSubElements(self) -> int: ...
	def ToBuildBVH(self) -> bool: ...

class MeshVS_Mesh(AIS_InteractiveObject):
	def __init__(self, theIsAllowOverlapped: Optional[bool] = False) -> None: ...
	def AcceptDisplayMode(self, theMode: int) -> bool: ...
	def AddBuilder(self, Builder: MeshVS_PrsBuilder, TreatAsHilighter: Optional[bool] = False) -> None: ...
	def ClearSelected(self) -> None: ...
	def Compute(self, PM: PrsMgr_PresentationManager3d, Prs: Prs3d_Presentation, DisplayMode: int) -> None: ...
	def ComputeSelection(self, Sel: SelectMgr_Selection, SelectMode: int) -> None: ...
	def FindBuilder(self, TypeString: str) -> MeshVS_PrsBuilder: ...
	def GetBuilder(self, Index: int) -> MeshVS_PrsBuilder: ...
	def GetBuilderById(self, Id: int) -> MeshVS_PrsBuilder: ...
	def GetBuildersCount(self) -> int: ...
	def GetDataSource(self) -> MeshVS_DataSource: ...
	def GetDrawer(self) -> MeshVS_Drawer: ...
	def GetFreeId(self) -> int: ...
	def GetHiddenElems(self) -> TColStd_HPackedMapOfInteger: ...
	def GetHiddenNodes(self) -> TColStd_HPackedMapOfInteger: ...
	def GetHilighter(self) -> MeshVS_PrsBuilder: ...
	def GetMeshSelMethod(self) -> MeshVS_MeshSelectionMethod: ...
	def GetOwnerMaps(self, IsElement: bool) -> MeshVS_DataMapOfIntegerOwner: ...
	def GetSelectableNodes(self) -> TColStd_HPackedMapOfInteger: ...
	def HilightOwnerWithColor(self, thePM: PrsMgr_PresentationManager3d, theColor: Prs3d_Drawer, theOwner: SelectMgr_EntityOwner) -> None: ...
	def HilightSelected(self, PM: PrsMgr_PresentationManager3d, Owners: SelectMgr_SequenceOfOwner) -> None: ...
	def IsHiddenElem(self, ID: int) -> bool: ...
	def IsHiddenNode(self, ID: int) -> bool: ...
	def IsSelectableElem(self, ID: int) -> bool: ...
	def IsSelectableNode(self, ID: int) -> bool: ...
	def IsWholeMeshOwner(self, theOwner: SelectMgr_EntityOwner) -> bool: ...
	def RemoveBuilder(self, Index: int) -> None: ...
	def RemoveBuilderById(self, Id: int) -> None: ...
	def SetDataSource(self, aDataSource: MeshVS_DataSource) -> None: ...
	def SetDrawer(self, aDrawer: MeshVS_Drawer) -> None: ...
	def SetHiddenElems(self, Ids: TColStd_HPackedMapOfInteger) -> None: ...
	def SetHiddenNodes(self, Ids: TColStd_HPackedMapOfInteger) -> None: ...
	@overload
	def SetHilighter(self, Builder: MeshVS_PrsBuilder) -> None: ...
	@overload
	def SetHilighter(self, Index: int) -> bool: ...
	def SetHilighterById(self, Id: int) -> bool: ...
	def SetMeshSelMethod(self, M: MeshVS_MeshSelectionMethod) -> None: ...
	def SetSelectableNodes(self, Ids: TColStd_HPackedMapOfInteger) -> None: ...
	def UpdateSelectableNodes(self) -> None: ...

class MeshVS_MeshEntityOwner(SelectMgr_EntityOwner):
	def __init__(self, SelObj: SelectMgr_SelectableObject, ID: int, MeshEntity: None, Type: MeshVS_EntityType, Priority: Optional[int] = 0, IsGroup: Optional[bool] = False) -> None: ...
	def Clear(self, PM: PrsMgr_PresentationManager, Mode: Optional[int] = 0) -> None: ...
	def HilightWithColor(self, thePM: PrsMgr_PresentationManager3d, theStyle: Prs3d_Drawer, theMode: Optional[int] = 0) -> None: ...
	def ID(self) -> int: ...
	def IsGroup(self) -> bool: ...
	def IsHilighted(self, PM: PrsMgr_PresentationManager, Mode: Optional[int] = 0) -> bool: ...
	def Owner(self) -> None: ...
	def Type(self) -> MeshVS_EntityType: ...
	def Unhilight(self, PM: PrsMgr_PresentationManager, Mode: Optional[int] = 0) -> None: ...

class MeshVS_MeshOwner(SelectMgr_EntityOwner):
	def __init__(self, theSelObj: SelectMgr_SelectableObject, theDS: MeshVS_DataSource, thePriority: Optional[int] = 0) -> None: ...
	def AddSelectedEntities(self, Nodes: TColStd_HPackedMapOfInteger, Elems: TColStd_HPackedMapOfInteger) -> None: ...
	def ClearSelectedEntities(self) -> None: ...
	def GetDataSource(self) -> MeshVS_DataSource: ...
	def GetDetectedElements(self) -> TColStd_HPackedMapOfInteger: ...
	def GetDetectedNodes(self) -> TColStd_HPackedMapOfInteger: ...
	def GetSelectedElements(self) -> TColStd_HPackedMapOfInteger: ...
	def GetSelectedNodes(self) -> TColStd_HPackedMapOfInteger: ...
	def HilightWithColor(self, thePM: PrsMgr_PresentationManager3d, theColor: Prs3d_Drawer, theMode: Optional[int] = 0) -> None: ...
	def IsForcedHilight(self) -> bool: ...
	def SetDetectedEntities(self, Nodes: TColStd_HPackedMapOfInteger, Elems: TColStd_HPackedMapOfInteger) -> None: ...
	def Unhilight(self, PM: PrsMgr_PresentationManager, Mode: Optional[int] = 0) -> None: ...

class MeshVS_PrsBuilder(Standard_Transient):
	def Build(self, Prs: Prs3d_Presentation, IDs: TColStd_PackedMapOfInteger, IDsToExclude: TColStd_PackedMapOfInteger, IsElement: bool, DisplayMode: int) -> None: ...
	def CustomBuild(self, Prs: Prs3d_Presentation, IDs: TColStd_PackedMapOfInteger, IDsToExclude: TColStd_PackedMapOfInteger, DisplayMode: int) -> None: ...
	def CustomSensitiveEntity(self, Owner: SelectMgr_EntityOwner, SelectMode: int) -> Select3D_SensitiveEntity: ...
	def GetDataSource(self) -> MeshVS_DataSource: ...
	def GetDrawer(self) -> MeshVS_Drawer: ...
	def GetFlags(self) -> int: ...
	def GetId(self) -> int: ...
	def GetPresentationManager(self) -> PrsMgr_PresentationManager3d: ...
	def GetPriority(self) -> int: ...
	def IsExcludingOn(self) -> bool: ...
	def SetDataSource(self, newDS: MeshVS_DataSource) -> None: ...
	def SetDrawer(self, newDr: MeshVS_Drawer) -> None: ...
	def SetExcluding(self, state: bool) -> None: ...
	def SetPresentationManager(self, thePrsMgr: PrsMgr_PresentationManager3d) -> None: ...
	def TestFlags(self, DisplayMode: int) -> bool: ...

class MeshVS_SensitiveFace(Select3D_SensitiveFace):
	def __init__(self, theOwner: SelectMgr_EntityOwner, thePoints: TColgp_Array1OfPnt, theSensType: Optional[Select3D_TypeOfSensitivity] = Select3D_TOS_INTERIOR) -> None: ...

class MeshVS_SensitiveMesh(Select3D_SensitiveEntity):
	def __init__(self, theOwner: SelectMgr_EntityOwner, theMode: Optional[int] = 0) -> None: ...
	def BoundingBox(self) -> Select3D_BndBox3d: ...
	def CenterOfGeometry(self) -> gp_Pnt: ...
	def GetConnected(self) -> Select3D_SensitiveEntity: ...
	def GetMode(self) -> int: ...
	def Matches(self, theMgr: SelectBasics_SelectingVolumeManager, thePickResult: SelectBasics_PickResult) -> bool: ...
	def NbSubElements(self) -> int: ...

class MeshVS_SensitivePolyhedron(Select3D_SensitiveEntity):
	def __init__(self, theOwner: SelectMgr_EntityOwner, theNodes: TColgp_Array1OfPnt, theTopo: MeshVS_HArray1OfSequenceOfInteger) -> None: ...
	def BoundingBox(self) -> Select3D_BndBox3d: ...
	def CenterOfGeometry(self) -> gp_Pnt: ...
	def GetConnected(self) -> Select3D_SensitiveEntity: ...
	def Matches(self, theMgr: SelectBasics_SelectingVolumeManager, thePickResult: SelectBasics_PickResult) -> bool: ...
	def NbSubElements(self) -> int: ...

class MeshVS_SensitiveQuad(Select3D_SensitiveEntity):
	@overload
	def __init__(self, theOwner: SelectMgr_EntityOwner, theQuadVerts: TColgp_Array1OfPnt) -> None: ...
	@overload
	def __init__(self, theOwner: SelectMgr_EntityOwner, thePnt1: gp_Pnt, thePnt2: gp_Pnt, thePnt3: gp_Pnt, thePnt4: gp_Pnt) -> None: ...
	def BoundingBox(self) -> Select3D_BndBox3d: ...
	def CenterOfGeometry(self) -> gp_Pnt: ...
	def GetConnected(self) -> Select3D_SensitiveEntity: ...
	def Matches(self, theMgr: SelectBasics_SelectingVolumeManager, thePickResult: SelectBasics_PickResult) -> bool: ...
	def NbSubElements(self) -> int: ...

class MeshVS_SensitiveSegment(Select3D_SensitiveSegment):
	def __init__(self, theOwner: SelectMgr_EntityOwner, theFirstPnt: gp_Pnt, theLastPnt: gp_Pnt) -> None: ...

class MeshVS_SymmetricPairHasher:
	@staticmethod
	def HashCode(theNodePair: MeshVS_NodePair, theUpperBound: int) -> int: ...
	@staticmethod
	def IsEqual(thePair1: MeshVS_NodePair, thePair2: MeshVS_NodePair) -> bool: ...

class MeshVS_Tool:
	@overload
	@staticmethod
	def CreateAspectFillArea3d(theDr: MeshVS_Drawer, UseDefaults: Optional[bool] = True) -> Graphic3d_AspectFillArea3d: ...
	@overload
	@staticmethod
	def CreateAspectFillArea3d(theDr: MeshVS_Drawer, Mat: Graphic3d_MaterialAspect, UseDefaults: Optional[bool] = True) -> Graphic3d_AspectFillArea3d: ...
	@staticmethod
	def CreateAspectLine3d(theDr: MeshVS_Drawer, UseDefaults: Optional[bool] = True) -> Graphic3d_AspectLine3d: ...
	@staticmethod
	def CreateAspectMarker3d(theDr: MeshVS_Drawer, UseDefaults: Optional[bool] = True) -> Graphic3d_AspectMarker3d: ...
	@staticmethod
	def CreateAspectText3d(theDr: MeshVS_Drawer, UseDefaults: Optional[bool] = True) -> Graphic3d_AspectText3d: ...
	@staticmethod
	def GetAverageNormal(Nodes: TColStd_Array1OfReal, Norm: gp_Vec) -> bool: ...
	@staticmethod
	def GetNormal(Nodes: TColStd_Array1OfReal, Norm: gp_Vec) -> bool: ...

class MeshVS_TwoColors:
	pass

class MeshVS_TwoNodes:
	def __init__(self, aFirst: Optional[int] = 0, aSecond: Optional[int] = 0) -> None: ...

class MeshVS_DataSource3D(MeshVS_DataSource):
	@staticmethod
	def CreatePrismTopology(BasePoints: int) -> MeshVS_HArray1OfSequenceOfInteger: ...
	@staticmethod
	def CreatePyramidTopology(BasePoints: int) -> MeshVS_HArray1OfSequenceOfInteger: ...
	def GetPrismTopology(self, BasePoints: int) -> MeshVS_HArray1OfSequenceOfInteger: ...
	def GetPyramidTopology(self, BasePoints: int) -> MeshVS_HArray1OfSequenceOfInteger: ...

class MeshVS_DeformedDataSource(MeshVS_DataSource):
	def __init__(self, theNonDeformDS: MeshVS_DataSource, theMagnify: float) -> None: ...
	def Get3DGeom(self, ID: int, Data: MeshVS_HArray1OfSequenceOfInteger) -> Tuple[bool, int]: ...
	def GetAddr(self, ID: int, IsElement: bool) -> None: ...
	def GetAllElements(self) -> TColStd_PackedMapOfInteger: ...
	def GetAllNodes(self) -> TColStd_PackedMapOfInteger: ...
	def GetGeom(self, ID: int, IsElement: bool, Coords: TColStd_Array1OfReal, Type: MeshVS_EntityType) -> Tuple[bool, int]: ...
	def GetGeomType(self, ID: int, IsElement: bool, Type: MeshVS_EntityType) -> bool: ...
	def GetMagnify(self) -> float: ...
	def GetNodesByElement(self, ID: int, NodeIDs: TColStd_Array1OfInteger) -> Tuple[bool, int]: ...
	def GetNonDeformedDataSource(self) -> MeshVS_DataSource: ...
	def GetVector(self, ID: int, Vect: gp_Vec) -> bool: ...
	def GetVectors(self) -> MeshVS_DataMapOfIntegerVector: ...
	def SetMagnify(self, theMagnify: float) -> None: ...
	def SetNonDeformedDataSource(self, theDS: MeshVS_DataSource) -> None: ...
	def SetVector(self, ID: int, Vect: gp_Vec) -> None: ...
	def SetVectors(self, Map: MeshVS_DataMapOfIntegerVector) -> None: ...

class MeshVS_ElementalColorPrsBuilder(MeshVS_PrsBuilder):
	def Build(self, Prs: Prs3d_Presentation, IDs: TColStd_PackedMapOfInteger, IDsToExclude: TColStd_PackedMapOfInteger, IsElement: bool, DisplayMode: int) -> None: ...
	def GetColor1(self, ID: int, theColor: Quantity_Color) -> bool: ...
	@overload
	def GetColor2(self, ID: int, theColor: MeshVS_TwoColors) -> bool: ...
	@overload
	def GetColor2(self, ID: int, theColor1: Quantity_Color, theColor2: Quantity_Color) -> bool: ...
	def GetColors1(self) -> MeshVS_DataMapOfIntegerColor: ...
	def GetColors2(self) -> MeshVS_DataMapOfIntegerTwoColors: ...
	def HasColors1(self) -> bool: ...
	def HasColors2(self) -> bool: ...
	def SetColor1(self, ID: int, theColor: Quantity_Color) -> None: ...
	@overload
	def SetColor2(self, ID: int, theTwoColors: MeshVS_TwoColors) -> None: ...
	@overload
	def SetColor2(self, ID: int, theColor1: Quantity_Color, theColor2: Quantity_Color) -> None: ...
	def SetColors1(self, Map: MeshVS_DataMapOfIntegerColor) -> None: ...
	def SetColors2(self, Map: MeshVS_DataMapOfIntegerTwoColors) -> None: ...

class MeshVS_MeshPrsBuilder(MeshVS_PrsBuilder):
	@staticmethod
	def AddVolumePrs(Topo: MeshVS_HArray1OfSequenceOfInteger, Nodes: TColStd_Array1OfReal, NbNodes: int, Array: Graphic3d_ArrayOfPrimitives, IsReflected: bool, IsShrinked: bool, IsSelect: bool, ShrinkCoef: float) -> None: ...
	def Build(self, Prs: Prs3d_Presentation, IDs: TColStd_PackedMapOfInteger, IDsToExclude: TColStd_PackedMapOfInteger, IsElement: bool, DisplayMode: int) -> None: ...
	def BuildElements(self, Prs: Prs3d_Presentation, IDs: TColStd_PackedMapOfInteger, IDsToExclude: TColStd_PackedMapOfInteger, DisplayMode: int) -> None: ...
	def BuildHilightPrs(self, Prs: Prs3d_Presentation, IDs: TColStd_PackedMapOfInteger, IsElement: bool) -> None: ...
	def BuildNodes(self, Prs: Prs3d_Presentation, IDs: TColStd_PackedMapOfInteger, IDsToExclude: TColStd_PackedMapOfInteger, DisplayMode: int) -> None: ...
	@staticmethod
	def HowManyPrimitives(Topo: MeshVS_HArray1OfSequenceOfInteger, AsPolygons: bool, IsSelect: bool, NbNodes: int) -> Tuple[int, int]: ...

class MeshVS_NodalColorPrsBuilder(MeshVS_PrsBuilder):
	def AddVolumePrs(self, theTopo: MeshVS_HArray1OfSequenceOfInteger, theNodes: TColStd_Array1OfInteger, theCoords: TColStd_Array1OfReal, theArray: Graphic3d_ArrayOfPrimitives, theIsShaded: bool, theNbColors: int, theNbTexColors: int, theColorRatio: float) -> None: ...
	def Build(self, Prs: Prs3d_Presentation, IDs: TColStd_PackedMapOfInteger, IDsToExclude: TColStd_PackedMapOfInteger, IsElement: bool, DisplayMode: int) -> None: ...
	def GetColor(self, ID: int, theColor: Quantity_Color) -> bool: ...
	def GetColorMap(self) -> Aspect_SequenceOfColor: ...
	def GetColors(self) -> MeshVS_DataMapOfIntegerColor: ...
	def GetInvalidColor(self) -> Quantity_Color: ...
	def GetTextureCoord(self, theID: int) -> float: ...
	def GetTextureCoords(self) -> TColStd_DataMapOfIntegerReal: ...
	def HasColors(self) -> bool: ...
	def IsUseTexture(self) -> bool: ...
	def SetColor(self, ID: int, theColor: Quantity_Color) -> None: ...
	def SetColorMap(self, theColors: Aspect_SequenceOfColor) -> None: ...
	def SetColors(self, Map: MeshVS_DataMapOfIntegerColor) -> None: ...
	def SetInvalidColor(self, theInvalidColor: Quantity_Color) -> None: ...
	def SetTextureCoord(self, theID: int, theCoord: float) -> None: ...
	def SetTextureCoords(self, theMap: TColStd_DataMapOfIntegerReal) -> None: ...
	def UseTexture(self, theToUse: bool) -> None: ...

class MeshVS_TextPrsBuilder(MeshVS_PrsBuilder):
	def Build(self, Prs: Prs3d_Presentation, IDs: TColStd_PackedMapOfInteger, IDsToExclude: TColStd_PackedMapOfInteger, IsElement: bool, theDisplayMode: int) -> None: ...
	def GetText(self, IsElement: bool, ID: int, Text: TCollection_AsciiString) -> bool: ...
	def GetTexts(self, IsElement: bool) -> MeshVS_DataMapOfIntegerAsciiString: ...
	def HasTexts(self, IsElement: bool) -> bool: ...
	def SetText(self, IsElement: bool, ID: int, Text: TCollection_AsciiString) -> None: ...
	def SetTexts(self, IsElement: bool, Map: MeshVS_DataMapOfIntegerAsciiString) -> None: ...

class MeshVS_VectorPrsBuilder(MeshVS_PrsBuilder):
	def Build(self, Prs: Prs3d_Presentation, IDs: TColStd_PackedMapOfInteger, IDsToExclude: TColStd_PackedMapOfInteger, IsElement: bool, theDisplayMode: int) -> None: ...
	def DrawVector(self, theTrsf: gp_Trsf, Length: float, MaxLength: float, ArrowPoints: TColgp_Array1OfPnt, Lines: Graphic3d_ArrayOfPrimitives, ArrowLines: Graphic3d_ArrayOfPrimitives, Triangles: Graphic3d_ArrayOfPrimitives) -> None: ...
	def GetMinMaxVectorValue(self, IsElement: bool) -> Tuple[float, float]: ...
	def GetVector(self, IsElement: bool, ID: int, Vect: gp_Vec) -> bool: ...
	def GetVectors(self, IsElement: bool) -> MeshVS_DataMapOfIntegerVector: ...
	def HasVectors(self, IsElement: bool) -> bool: ...
	def SetSimplePrsMode(self, IsSimpleArrow: bool) -> None: ...
	def SetSimplePrsParams(self, theLineWidthParam: float, theStartParam: float, theEndParam: float) -> None: ...
	def SetVector(self, IsElement: bool, ID: int, Vect: gp_Vec) -> None: ...
	def SetVectors(self, IsElement: bool, Map: MeshVS_DataMapOfIntegerVector) -> None: ...
	@staticmethod
	def calculateArrow(Points: TColgp_Array1OfPnt, Length: float, ArrowPart: float) -> float: ...

# harray1 classes

class MeshVS_HArray1OfSequenceOfInteger(MeshVS_Array1OfSequenceOfInteger, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> MeshVS_Array1OfSequenceOfInteger: ...

# harray2 classes
# hsequence classes

MeshVS_SymmetricPairHasher_HashCode = MeshVS_SymmetricPairHasher.HashCode
MeshVS_SymmetricPairHasher_IsEqual = MeshVS_SymmetricPairHasher.IsEqual
MeshVS_Tool_CreateAspectFillArea3d = MeshVS_Tool.CreateAspectFillArea3d
MeshVS_Tool_CreateAspectFillArea3d = MeshVS_Tool.CreateAspectFillArea3d
MeshVS_Tool_CreateAspectLine3d = MeshVS_Tool.CreateAspectLine3d
MeshVS_Tool_CreateAspectMarker3d = MeshVS_Tool.CreateAspectMarker3d
MeshVS_Tool_CreateAspectText3d = MeshVS_Tool.CreateAspectText3d
MeshVS_Tool_GetAverageNormal = MeshVS_Tool.GetAverageNormal
MeshVS_Tool_GetNormal = MeshVS_Tool.GetNormal
MeshVS_DataSource3D_CreatePrismTopology = MeshVS_DataSource3D.CreatePrismTopology
MeshVS_DataSource3D_CreatePyramidTopology = MeshVS_DataSource3D.CreatePyramidTopology
MeshVS_MeshPrsBuilder_AddVolumePrs = MeshVS_MeshPrsBuilder.AddVolumePrs
MeshVS_MeshPrsBuilder_HowManyPrimitives = MeshVS_MeshPrsBuilder.HowManyPrimitives
MeshVS_VectorPrsBuilder_calculateArrow = MeshVS_VectorPrsBuilder.calculateArrow



from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.StepBasic import *
from OCC.Core.TCollection import *
from OCC.Core.StepVisual import *
from OCC.Core.StepData import *
from OCC.Core.StepRepr import *
from OCC.Core.StepShape import *
from OCC.Core.StepGeom import *
from OCC.Core.Interface import *


class StepAP214_Array1OfApprovalItem:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> StepAP214_ApprovalItem: ...
    def __setitem__(self, index: int, value: StepAP214_ApprovalItem) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[StepAP214_ApprovalItem]: ...
    def next(self) -> StepAP214_ApprovalItem: ...
    __next__ = next
    def Init(self, theValue: StepAP214_ApprovalItem) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> StepAP214_ApprovalItem: ...
    def Last(self) -> StepAP214_ApprovalItem: ...
    def Value(self, theIndex: int) -> StepAP214_ApprovalItem: ...
    def SetValue(self, theIndex: int, theValue: StepAP214_ApprovalItem) -> None: ...

class StepAP214_Array1OfAutoDesignDateAndPersonItem:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> StepAP214_AutoDesignDateAndPersonItem: ...
    def __setitem__(self, index: int, value: StepAP214_AutoDesignDateAndPersonItem) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[StepAP214_AutoDesignDateAndPersonItem]: ...
    def next(self) -> StepAP214_AutoDesignDateAndPersonItem: ...
    __next__ = next
    def Init(self, theValue: StepAP214_AutoDesignDateAndPersonItem) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> StepAP214_AutoDesignDateAndPersonItem: ...
    def Last(self) -> StepAP214_AutoDesignDateAndPersonItem: ...
    def Value(self, theIndex: int) -> StepAP214_AutoDesignDateAndPersonItem: ...
    def SetValue(self, theIndex: int, theValue: StepAP214_AutoDesignDateAndPersonItem) -> None: ...

class StepAP214_Array1OfAutoDesignDateAndTimeItem:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> StepAP214_AutoDesignDateAndTimeItem: ...
    def __setitem__(self, index: int, value: StepAP214_AutoDesignDateAndTimeItem) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[StepAP214_AutoDesignDateAndTimeItem]: ...
    def next(self) -> StepAP214_AutoDesignDateAndTimeItem: ...
    __next__ = next
    def Init(self, theValue: StepAP214_AutoDesignDateAndTimeItem) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> StepAP214_AutoDesignDateAndTimeItem: ...
    def Last(self) -> StepAP214_AutoDesignDateAndTimeItem: ...
    def Value(self, theIndex: int) -> StepAP214_AutoDesignDateAndTimeItem: ...
    def SetValue(self, theIndex: int, theValue: StepAP214_AutoDesignDateAndTimeItem) -> None: ...

class StepAP214_Array1OfAutoDesignDatedItem:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> StepAP214_AutoDesignDatedItem: ...
    def __setitem__(self, index: int, value: StepAP214_AutoDesignDatedItem) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[StepAP214_AutoDesignDatedItem]: ...
    def next(self) -> StepAP214_AutoDesignDatedItem: ...
    __next__ = next
    def Init(self, theValue: StepAP214_AutoDesignDatedItem) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> StepAP214_AutoDesignDatedItem: ...
    def Last(self) -> StepAP214_AutoDesignDatedItem: ...
    def Value(self, theIndex: int) -> StepAP214_AutoDesignDatedItem: ...
    def SetValue(self, theIndex: int, theValue: StepAP214_AutoDesignDatedItem) -> None: ...

class StepAP214_Array1OfAutoDesignGeneralOrgItem:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> StepAP214_AutoDesignGeneralOrgItem: ...
    def __setitem__(self, index: int, value: StepAP214_AutoDesignGeneralOrgItem) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[StepAP214_AutoDesignGeneralOrgItem]: ...
    def next(self) -> StepAP214_AutoDesignGeneralOrgItem: ...
    __next__ = next
    def Init(self, theValue: StepAP214_AutoDesignGeneralOrgItem) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> StepAP214_AutoDesignGeneralOrgItem: ...
    def Last(self) -> StepAP214_AutoDesignGeneralOrgItem: ...
    def Value(self, theIndex: int) -> StepAP214_AutoDesignGeneralOrgItem: ...
    def SetValue(self, theIndex: int, theValue: StepAP214_AutoDesignGeneralOrgItem) -> None: ...

class StepAP214_Array1OfAutoDesignGroupedItem:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> StepAP214_AutoDesignGroupedItem: ...
    def __setitem__(self, index: int, value: StepAP214_AutoDesignGroupedItem) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[StepAP214_AutoDesignGroupedItem]: ...
    def next(self) -> StepAP214_AutoDesignGroupedItem: ...
    __next__ = next
    def Init(self, theValue: StepAP214_AutoDesignGroupedItem) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> StepAP214_AutoDesignGroupedItem: ...
    def Last(self) -> StepAP214_AutoDesignGroupedItem: ...
    def Value(self, theIndex: int) -> StepAP214_AutoDesignGroupedItem: ...
    def SetValue(self, theIndex: int, theValue: StepAP214_AutoDesignGroupedItem) -> None: ...

class StepAP214_Array1OfAutoDesignPresentedItemSelect:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> StepAP214_AutoDesignPresentedItemSelect: ...
    def __setitem__(self, index: int, value: StepAP214_AutoDesignPresentedItemSelect) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[StepAP214_AutoDesignPresentedItemSelect]: ...
    def next(self) -> StepAP214_AutoDesignPresentedItemSelect: ...
    __next__ = next
    def Init(self, theValue: StepAP214_AutoDesignPresentedItemSelect) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> StepAP214_AutoDesignPresentedItemSelect: ...
    def Last(self) -> StepAP214_AutoDesignPresentedItemSelect: ...
    def Value(self, theIndex: int) -> StepAP214_AutoDesignPresentedItemSelect: ...
    def SetValue(self, theIndex: int, theValue: StepAP214_AutoDesignPresentedItemSelect) -> None: ...

class StepAP214_Array1OfAutoDesignReferencingItem:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> StepAP214_AutoDesignReferencingItem: ...
    def __setitem__(self, index: int, value: StepAP214_AutoDesignReferencingItem) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[StepAP214_AutoDesignReferencingItem]: ...
    def next(self) -> StepAP214_AutoDesignReferencingItem: ...
    __next__ = next
    def Init(self, theValue: StepAP214_AutoDesignReferencingItem) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> StepAP214_AutoDesignReferencingItem: ...
    def Last(self) -> StepAP214_AutoDesignReferencingItem: ...
    def Value(self, theIndex: int) -> StepAP214_AutoDesignReferencingItem: ...
    def SetValue(self, theIndex: int, theValue: StepAP214_AutoDesignReferencingItem) -> None: ...

class StepAP214_Array1OfDateAndTimeItem:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> StepAP214_DateAndTimeItem: ...
    def __setitem__(self, index: int, value: StepAP214_DateAndTimeItem) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[StepAP214_DateAndTimeItem]: ...
    def next(self) -> StepAP214_DateAndTimeItem: ...
    __next__ = next
    def Init(self, theValue: StepAP214_DateAndTimeItem) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> StepAP214_DateAndTimeItem: ...
    def Last(self) -> StepAP214_DateAndTimeItem: ...
    def Value(self, theIndex: int) -> StepAP214_DateAndTimeItem: ...
    def SetValue(self, theIndex: int, theValue: StepAP214_DateAndTimeItem) -> None: ...

class StepAP214_Array1OfDateItem:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> StepAP214_DateItem: ...
    def __setitem__(self, index: int, value: StepAP214_DateItem) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[StepAP214_DateItem]: ...
    def next(self) -> StepAP214_DateItem: ...
    __next__ = next
    def Init(self, theValue: StepAP214_DateItem) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> StepAP214_DateItem: ...
    def Last(self) -> StepAP214_DateItem: ...
    def Value(self, theIndex: int) -> StepAP214_DateItem: ...
    def SetValue(self, theIndex: int, theValue: StepAP214_DateItem) -> None: ...

class StepAP214_Array1OfDocumentReferenceItem:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> StepAP214_DocumentReferenceItem: ...
    def __setitem__(self, index: int, value: StepAP214_DocumentReferenceItem) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[StepAP214_DocumentReferenceItem]: ...
    def next(self) -> StepAP214_DocumentReferenceItem: ...
    __next__ = next
    def Init(self, theValue: StepAP214_DocumentReferenceItem) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> StepAP214_DocumentReferenceItem: ...
    def Last(self) -> StepAP214_DocumentReferenceItem: ...
    def Value(self, theIndex: int) -> StepAP214_DocumentReferenceItem: ...
    def SetValue(self, theIndex: int, theValue: StepAP214_DocumentReferenceItem) -> None: ...

class StepAP214_Array1OfExternalIdentificationItem:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> StepAP214_ExternalIdentificationItem: ...
    def __setitem__(self, index: int, value: StepAP214_ExternalIdentificationItem) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[StepAP214_ExternalIdentificationItem]: ...
    def next(self) -> StepAP214_ExternalIdentificationItem: ...
    __next__ = next
    def Init(self, theValue: StepAP214_ExternalIdentificationItem) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> StepAP214_ExternalIdentificationItem: ...
    def Last(self) -> StepAP214_ExternalIdentificationItem: ...
    def Value(self, theIndex: int) -> StepAP214_ExternalIdentificationItem: ...
    def SetValue(self, theIndex: int, theValue: StepAP214_ExternalIdentificationItem) -> None: ...

class StepAP214_Array1OfGroupItem:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> StepAP214_GroupItem: ...
    def __setitem__(self, index: int, value: StepAP214_GroupItem) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[StepAP214_GroupItem]: ...
    def next(self) -> StepAP214_GroupItem: ...
    __next__ = next
    def Init(self, theValue: StepAP214_GroupItem) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> StepAP214_GroupItem: ...
    def Last(self) -> StepAP214_GroupItem: ...
    def Value(self, theIndex: int) -> StepAP214_GroupItem: ...
    def SetValue(self, theIndex: int, theValue: StepAP214_GroupItem) -> None: ...

class StepAP214_Array1OfOrganizationItem:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> StepAP214_OrganizationItem: ...
    def __setitem__(self, index: int, value: StepAP214_OrganizationItem) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[StepAP214_OrganizationItem]: ...
    def next(self) -> StepAP214_OrganizationItem: ...
    __next__ = next
    def Init(self, theValue: StepAP214_OrganizationItem) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> StepAP214_OrganizationItem: ...
    def Last(self) -> StepAP214_OrganizationItem: ...
    def Value(self, theIndex: int) -> StepAP214_OrganizationItem: ...
    def SetValue(self, theIndex: int, theValue: StepAP214_OrganizationItem) -> None: ...

class StepAP214_Array1OfPersonAndOrganizationItem:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> StepAP214_PersonAndOrganizationItem: ...
    def __setitem__(self, index: int, value: StepAP214_PersonAndOrganizationItem) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[StepAP214_PersonAndOrganizationItem]: ...
    def next(self) -> StepAP214_PersonAndOrganizationItem: ...
    __next__ = next
    def Init(self, theValue: StepAP214_PersonAndOrganizationItem) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> StepAP214_PersonAndOrganizationItem: ...
    def Last(self) -> StepAP214_PersonAndOrganizationItem: ...
    def Value(self, theIndex: int) -> StepAP214_PersonAndOrganizationItem: ...
    def SetValue(self, theIndex: int, theValue: StepAP214_PersonAndOrganizationItem) -> None: ...

class StepAP214_Array1OfPresentedItemSelect:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> StepAP214_PresentedItemSelect: ...
    def __setitem__(self, index: int, value: StepAP214_PresentedItemSelect) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[StepAP214_PresentedItemSelect]: ...
    def next(self) -> StepAP214_PresentedItemSelect: ...
    __next__ = next
    def Init(self, theValue: StepAP214_PresentedItemSelect) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> StepAP214_PresentedItemSelect: ...
    def Last(self) -> StepAP214_PresentedItemSelect: ...
    def Value(self, theIndex: int) -> StepAP214_PresentedItemSelect: ...
    def SetValue(self, theIndex: int, theValue: StepAP214_PresentedItemSelect) -> None: ...

class StepAP214_Array1OfSecurityClassificationItem:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> StepAP214_SecurityClassificationItem: ...
    def __setitem__(self, index: int, value: StepAP214_SecurityClassificationItem) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[StepAP214_SecurityClassificationItem]: ...
    def next(self) -> StepAP214_SecurityClassificationItem: ...
    __next__ = next
    def Init(self, theValue: StepAP214_SecurityClassificationItem) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> StepAP214_SecurityClassificationItem: ...
    def Last(self) -> StepAP214_SecurityClassificationItem: ...
    def Value(self, theIndex: int) -> StepAP214_SecurityClassificationItem: ...
    def SetValue(self, theIndex: int, theValue: StepAP214_SecurityClassificationItem) -> None: ...

class stepap214:
	@staticmethod
	def Protocol() -> StepAP214_Protocol: ...

class StepAP214_AppliedApprovalAssignment(StepBasic_ApprovalAssignment):
	def __init__(self) -> None: ...
	def Init(self, aAssignedApproval: StepBasic_Approval, aItems: StepAP214_HArray1OfApprovalItem) -> None: ...
	def Items(self) -> StepAP214_HArray1OfApprovalItem: ...
	def ItemsValue(self, num: int) -> StepAP214_ApprovalItem: ...
	def NbItems(self) -> int: ...
	def SetItems(self, aItems: StepAP214_HArray1OfApprovalItem) -> None: ...

class StepAP214_AppliedDateAndTimeAssignment(StepBasic_DateAndTimeAssignment):
	def __init__(self) -> None: ...
	def Init(self, aAssignedDateAndTime: StepBasic_DateAndTime, aRole: StepBasic_DateTimeRole, aItems: StepAP214_HArray1OfDateAndTimeItem) -> None: ...
	def Items(self) -> StepAP214_HArray1OfDateAndTimeItem: ...
	def ItemsValue(self, num: int) -> StepAP214_DateAndTimeItem: ...
	def NbItems(self) -> int: ...
	def SetItems(self, aItems: StepAP214_HArray1OfDateAndTimeItem) -> None: ...

class StepAP214_AppliedDateAssignment(StepBasic_DateAssignment):
	def __init__(self) -> None: ...
	def Init(self, aAssignedDate: StepBasic_Date, aRole: StepBasic_DateRole, aItems: StepAP214_HArray1OfDateItem) -> None: ...
	def Items(self) -> StepAP214_HArray1OfDateItem: ...
	def ItemsValue(self, num: int) -> StepAP214_DateItem: ...
	def NbItems(self) -> int: ...
	def SetItems(self, aItems: StepAP214_HArray1OfDateItem) -> None: ...

class StepAP214_AppliedDocumentReference(StepBasic_DocumentReference):
	def __init__(self) -> None: ...
	def Init(self, aAssignedDocument: StepBasic_Document, aSource: TCollection_HAsciiString, aItems: StepAP214_HArray1OfDocumentReferenceItem) -> None: ...
	def Items(self) -> StepAP214_HArray1OfDocumentReferenceItem: ...
	def ItemsValue(self, num: int) -> StepAP214_DocumentReferenceItem: ...
	def NbItems(self) -> int: ...
	def SetItems(self, aItems: StepAP214_HArray1OfDocumentReferenceItem) -> None: ...

class StepAP214_AppliedExternalIdentificationAssignment(StepBasic_ExternalIdentificationAssignment):
	def __init__(self) -> None: ...
	def Init(self, aIdentificationAssignment_AssignedId: TCollection_HAsciiString, aIdentificationAssignment_Role: StepBasic_IdentificationRole, aExternalIdentificationAssignment_Source: StepBasic_ExternalSource, aItems: StepAP214_HArray1OfExternalIdentificationItem) -> None: ...
	def Items(self) -> StepAP214_HArray1OfExternalIdentificationItem: ...
	def SetItems(self, Items: StepAP214_HArray1OfExternalIdentificationItem) -> None: ...

class StepAP214_AppliedGroupAssignment(StepBasic_GroupAssignment):
	def __init__(self) -> None: ...
	def Init(self, aGroupAssignment_AssignedGroup: StepBasic_Group, aItems: StepAP214_HArray1OfGroupItem) -> None: ...
	def Items(self) -> StepAP214_HArray1OfGroupItem: ...
	def SetItems(self, Items: StepAP214_HArray1OfGroupItem) -> None: ...

class StepAP214_AppliedOrganizationAssignment(StepBasic_OrganizationAssignment):
	def __init__(self) -> None: ...
	def Init(self, aAssignedOrganization: StepBasic_Organization, aRole: StepBasic_OrganizationRole, aItems: StepAP214_HArray1OfOrganizationItem) -> None: ...
	def Items(self) -> StepAP214_HArray1OfOrganizationItem: ...
	def ItemsValue(self, num: int) -> StepAP214_OrganizationItem: ...
	def NbItems(self) -> int: ...
	def SetItems(self, aItems: StepAP214_HArray1OfOrganizationItem) -> None: ...

class StepAP214_AppliedPersonAndOrganizationAssignment(StepBasic_PersonAndOrganizationAssignment):
	def __init__(self) -> None: ...
	def Init(self, aAssignedPersonAndOrganization: StepBasic_PersonAndOrganization, aRole: StepBasic_PersonAndOrganizationRole, aItems: StepAP214_HArray1OfPersonAndOrganizationItem) -> None: ...
	def Items(self) -> StepAP214_HArray1OfPersonAndOrganizationItem: ...
	def ItemsValue(self, num: int) -> StepAP214_PersonAndOrganizationItem: ...
	def NbItems(self) -> int: ...
	def SetItems(self, aItems: StepAP214_HArray1OfPersonAndOrganizationItem) -> None: ...

class StepAP214_AppliedPresentedItem(StepVisual_PresentedItem):
	def __init__(self) -> None: ...
	def Init(self, aItems: StepAP214_HArray1OfPresentedItemSelect) -> None: ...
	def Items(self) -> StepAP214_HArray1OfPresentedItemSelect: ...
	def ItemsValue(self, num: int) -> StepAP214_PresentedItemSelect: ...
	def NbItems(self) -> int: ...
	def SetItems(self, aItems: StepAP214_HArray1OfPresentedItemSelect) -> None: ...

class StepAP214_AppliedSecurityClassificationAssignment(StepBasic_SecurityClassificationAssignment):
	def __init__(self) -> None: ...
	def Init(self, aAssignedSecurityClassification: StepBasic_SecurityClassification, aItems: StepAP214_HArray1OfSecurityClassificationItem) -> None: ...
	def Items(self) -> StepAP214_HArray1OfSecurityClassificationItem: ...
	def ItemsValue(self, num: int) -> StepAP214_SecurityClassificationItem: ...
	def NbItems(self) -> int: ...
	def SetItems(self, aItems: StepAP214_HArray1OfSecurityClassificationItem) -> None: ...

class StepAP214_ApprovalItem(StepData_SelectType):
	def __init__(self) -> None: ...
	def AssemblyComponentUsageSubstitute(self) -> StepRepr_AssemblyComponentUsageSubstitute: ...
	def CaseNum(self, ent: Standard_Transient) -> int: ...
	def ConfigurationItem(self) -> StepRepr_ConfigurationItem: ...
	def Date(self) -> StepBasic_Date: ...
	def Document(self) -> StepBasic_Document: ...
	def DocumentFile(self) -> StepBasic_DocumentFile: ...
	def Effectivity(self) -> StepBasic_Effectivity: ...
	def Group(self) -> StepBasic_Group: ...
	def GroupRelationship(self) -> StepBasic_GroupRelationship: ...
	def MaterialDesignation(self) -> StepRepr_MaterialDesignation: ...
	def MechanicalDesignGeometricPresentationRepresentation(self) -> StepVisual_MechanicalDesignGeometricPresentationRepresentation: ...
	def PresentationArea(self) -> StepVisual_PresentationArea: ...
	def Product(self) -> StepBasic_Product: ...
	def ProductDefinition(self) -> StepBasic_ProductDefinition: ...
	def ProductDefinitionFormation(self) -> StepBasic_ProductDefinitionFormation: ...
	def ProductDefinitionFormationRelationship(self) -> StepBasic_ProductDefinitionFormationRelationship: ...
	def ProductDefinitionRelationship(self) -> StepBasic_ProductDefinitionRelationship: ...
	def PropertyDefinition(self) -> StepRepr_PropertyDefinition: ...
	def Representation(self) -> StepRepr_Representation: ...
	def SecurityClassification(self) -> StepBasic_SecurityClassification: ...
	def ShapeAspectRelationship(self) -> StepRepr_ShapeAspectRelationship: ...
	def ShapeRepresentation(self) -> StepShape_ShapeRepresentation: ...

class StepAP214_AutoDesignActualDateAndTimeAssignment(StepBasic_DateAndTimeAssignment):
	def __init__(self) -> None: ...
	def Init(self, aAssignedDateAndTime: StepBasic_DateAndTime, aRole: StepBasic_DateTimeRole, aItems: StepAP214_HArray1OfAutoDesignDateAndTimeItem) -> None: ...
	def Items(self) -> StepAP214_HArray1OfAutoDesignDateAndTimeItem: ...
	def ItemsValue(self, num: int) -> StepAP214_AutoDesignDateAndTimeItem: ...
	def NbItems(self) -> int: ...
	def SetItems(self, aItems: StepAP214_HArray1OfAutoDesignDateAndTimeItem) -> None: ...

class StepAP214_AutoDesignActualDateAssignment(StepBasic_DateAssignment):
	def __init__(self) -> None: ...
	def Init(self, aAssignedDate: StepBasic_Date, aRole: StepBasic_DateRole, aItems: StepAP214_HArray1OfAutoDesignDatedItem) -> None: ...
	def Items(self) -> StepAP214_HArray1OfAutoDesignDatedItem: ...
	def ItemsValue(self, num: int) -> StepAP214_AutoDesignDatedItem: ...
	def NbItems(self) -> int: ...
	def SetItems(self, aItems: StepAP214_HArray1OfAutoDesignDatedItem) -> None: ...

class StepAP214_AutoDesignApprovalAssignment(StepBasic_ApprovalAssignment):
	def __init__(self) -> None: ...
	def Init(self, aAssignedApproval: StepBasic_Approval, aItems: StepAP214_HArray1OfAutoDesignGeneralOrgItem) -> None: ...
	def Items(self) -> StepAP214_HArray1OfAutoDesignGeneralOrgItem: ...
	def ItemsValue(self, num: int) -> StepAP214_AutoDesignGeneralOrgItem: ...
	def NbItems(self) -> int: ...
	def SetItems(self, aItems: StepAP214_HArray1OfAutoDesignGeneralOrgItem) -> None: ...

class StepAP214_AutoDesignDateAndPersonAssignment(StepBasic_PersonAndOrganizationAssignment):
	def __init__(self) -> None: ...
	def Init(self, aAssignedPersonAndOrganization: StepBasic_PersonAndOrganization, aRole: StepBasic_PersonAndOrganizationRole, aItems: StepAP214_HArray1OfAutoDesignDateAndPersonItem) -> None: ...
	def Items(self) -> StepAP214_HArray1OfAutoDesignDateAndPersonItem: ...
	def ItemsValue(self, num: int) -> StepAP214_AutoDesignDateAndPersonItem: ...
	def NbItems(self) -> int: ...
	def SetItems(self, aItems: StepAP214_HArray1OfAutoDesignDateAndPersonItem) -> None: ...

class StepAP214_AutoDesignDateAndPersonItem(StepData_SelectType):
	def __init__(self) -> None: ...
	def AutoDesignDocumentReference(self) -> StepAP214_AutoDesignDocumentReference: ...
	def AutoDesignOrganizationAssignment(self) -> StepAP214_AutoDesignOrganizationAssignment: ...
	def CaseNum(self, ent: Standard_Transient) -> int: ...
	def ExternallyDefinedRepresentation(self) -> StepRepr_ExternallyDefinedRepresentation: ...
	def Product(self) -> StepBasic_Product: ...
	def ProductDefinition(self) -> StepBasic_ProductDefinition: ...
	def ProductDefinitionFormation(self) -> StepBasic_ProductDefinitionFormation: ...
	def ProductDefinitionRelationship(self) -> StepBasic_ProductDefinitionRelationship: ...
	def ProductDefinitionWithAssociatedDocuments(self) -> StepBasic_ProductDefinitionWithAssociatedDocuments: ...
	def Representation(self) -> StepRepr_Representation: ...

class StepAP214_AutoDesignDateAndTimeItem(StepData_SelectType):
	def __init__(self) -> None: ...
	def ApprovalPersonOrganization(self) -> StepBasic_ApprovalPersonOrganization: ...
	def AutoDesignDateAndPersonAssignment(self) -> StepAP214_AutoDesignDateAndPersonAssignment: ...
	def CaseNum(self, ent: Standard_Transient) -> int: ...
	def ProductDefinitionEffectivity(self) -> StepBasic_ProductDefinitionEffectivity: ...

class StepAP214_AutoDesignDatedItem(StepData_SelectType):
	def __init__(self) -> None: ...
	def ApprovalPersonOrganization(self) -> StepBasic_ApprovalPersonOrganization: ...
	def AutoDesignDateAndPersonAssignment(self) -> StepAP214_AutoDesignDateAndPersonAssignment: ...
	def CaseNum(self, ent: Standard_Transient) -> int: ...
	def ProductDefinitionEffectivity(self) -> StepBasic_ProductDefinitionEffectivity: ...

class StepAP214_AutoDesignDocumentReference(StepBasic_DocumentReference):
	def __init__(self) -> None: ...
	def Init(self, aAssignedDocument: StepBasic_Document, aSource: TCollection_HAsciiString, aItems: StepAP214_HArray1OfAutoDesignReferencingItem) -> None: ...
	def Items(self) -> StepAP214_HArray1OfAutoDesignReferencingItem: ...
	def ItemsValue(self, num: int) -> StepAP214_AutoDesignReferencingItem: ...
	def NbItems(self) -> int: ...
	def SetItems(self, aItems: StepAP214_HArray1OfAutoDesignReferencingItem) -> None: ...

class StepAP214_AutoDesignGeneralOrgItem(StepData_SelectType):
	def __init__(self) -> None: ...
	def AutoDesignDocumentReference(self) -> StepAP214_AutoDesignDocumentReference: ...
	def CaseNum(self, ent: Standard_Transient) -> int: ...
	def ExternallyDefinedRepresentation(self) -> StepRepr_ExternallyDefinedRepresentation: ...
	def Product(self) -> StepBasic_Product: ...
	def ProductDefinition(self) -> StepBasic_ProductDefinition: ...
	def ProductDefinitionFormation(self) -> StepBasic_ProductDefinitionFormation: ...
	def ProductDefinitionRelationship(self) -> StepBasic_ProductDefinitionRelationship: ...
	def ProductDefinitionWithAssociatedDocuments(self) -> StepBasic_ProductDefinitionWithAssociatedDocuments: ...
	def Representation(self) -> StepRepr_Representation: ...

class StepAP214_AutoDesignGroupAssignment(StepBasic_GroupAssignment):
	def __init__(self) -> None: ...
	def Init(self, aAssignedGroup: StepBasic_Group, aItems: StepAP214_HArray1OfAutoDesignGroupedItem) -> None: ...
	def Items(self) -> StepAP214_HArray1OfAutoDesignGroupedItem: ...
	def ItemsValue(self, num: int) -> StepAP214_AutoDesignGroupedItem: ...
	def NbItems(self) -> int: ...
	def SetItems(self, aItems: StepAP214_HArray1OfAutoDesignGroupedItem) -> None: ...

class StepAP214_AutoDesignGroupedItem(StepData_SelectType):
	def __init__(self) -> None: ...
	def AdvancedBrepShapeRepresentation(self) -> StepShape_AdvancedBrepShapeRepresentation: ...
	def CaseNum(self, ent: Standard_Transient) -> int: ...
	def CsgShapeRepresentation(self) -> StepShape_CsgShapeRepresentation: ...
	def FacetedBrepShapeRepresentation(self) -> StepShape_FacetedBrepShapeRepresentation: ...
	def GeometricallyBoundedSurfaceShapeRepresentation(self) -> StepShape_GeometricallyBoundedSurfaceShapeRepresentation: ...
	def GeometricallyBoundedWireframeShapeRepresentation(self) -> StepShape_GeometricallyBoundedWireframeShapeRepresentation: ...
	def ManifoldSurfaceShapeRepresentation(self) -> StepShape_ManifoldSurfaceShapeRepresentation: ...
	def Representation(self) -> StepRepr_Representation: ...
	def RepresentationItem(self) -> StepRepr_RepresentationItem: ...
	def ShapeAspect(self) -> StepRepr_ShapeAspect: ...
	def ShapeRepresentation(self) -> StepShape_ShapeRepresentation: ...
	def TemplateInstance(self) -> StepVisual_TemplateInstance: ...

class StepAP214_AutoDesignNominalDateAndTimeAssignment(StepBasic_DateAndTimeAssignment):
	def __init__(self) -> None: ...
	def Init(self, aAssignedDateAndTime: StepBasic_DateAndTime, aRole: StepBasic_DateTimeRole, aItems: StepAP214_HArray1OfAutoDesignDateAndTimeItem) -> None: ...
	def Items(self) -> StepAP214_HArray1OfAutoDesignDateAndTimeItem: ...
	def ItemsValue(self, num: int) -> StepAP214_AutoDesignDateAndTimeItem: ...
	def NbItems(self) -> int: ...
	def SetItems(self, aItems: StepAP214_HArray1OfAutoDesignDateAndTimeItem) -> None: ...

class StepAP214_AutoDesignNominalDateAssignment(StepBasic_DateAssignment):
	def __init__(self) -> None: ...
	def Init(self, aAssignedDate: StepBasic_Date, aRole: StepBasic_DateRole, aItems: StepAP214_HArray1OfAutoDesignDatedItem) -> None: ...
	def Items(self) -> StepAP214_HArray1OfAutoDesignDatedItem: ...
	def ItemsValue(self, num: int) -> StepAP214_AutoDesignDatedItem: ...
	def NbItems(self) -> int: ...
	def SetItems(self, aItems: StepAP214_HArray1OfAutoDesignDatedItem) -> None: ...

class StepAP214_AutoDesignOrganizationAssignment(StepBasic_OrganizationAssignment):
	def __init__(self) -> None: ...
	def Init(self, aAssignedOrganization: StepBasic_Organization, aRole: StepBasic_OrganizationRole, aItems: StepAP214_HArray1OfAutoDesignGeneralOrgItem) -> None: ...
	def Items(self) -> StepAP214_HArray1OfAutoDesignGeneralOrgItem: ...
	def ItemsValue(self, num: int) -> StepAP214_AutoDesignGeneralOrgItem: ...
	def NbItems(self) -> int: ...
	def SetItems(self, aItems: StepAP214_HArray1OfAutoDesignGeneralOrgItem) -> None: ...

class StepAP214_AutoDesignPersonAndOrganizationAssignment(StepBasic_PersonAndOrganizationAssignment):
	def __init__(self) -> None: ...
	def Init(self, aAssignedPersonAndOrganization: StepBasic_PersonAndOrganization, aRole: StepBasic_PersonAndOrganizationRole, aItems: StepAP214_HArray1OfAutoDesignGeneralOrgItem) -> None: ...
	def Items(self) -> StepAP214_HArray1OfAutoDesignGeneralOrgItem: ...
	def ItemsValue(self, num: int) -> StepAP214_AutoDesignGeneralOrgItem: ...
	def NbItems(self) -> int: ...
	def SetItems(self, aItems: StepAP214_HArray1OfAutoDesignGeneralOrgItem) -> None: ...

class StepAP214_AutoDesignPresentedItem(StepVisual_PresentedItem):
	def __init__(self) -> None: ...
	def Init(self, aItems: StepAP214_HArray1OfAutoDesignPresentedItemSelect) -> None: ...
	def Items(self) -> StepAP214_HArray1OfAutoDesignPresentedItemSelect: ...
	def ItemsValue(self, num: int) -> StepAP214_AutoDesignPresentedItemSelect: ...
	def NbItems(self) -> int: ...
	def SetItems(self, aItems: StepAP214_HArray1OfAutoDesignPresentedItemSelect) -> None: ...

class StepAP214_AutoDesignPresentedItemSelect(StepData_SelectType):
	def __init__(self) -> None: ...
	def CaseNum(self, ent: Standard_Transient) -> int: ...
	def DocumentRelationship(self) -> StepBasic_DocumentRelationship: ...
	def ProductDefinition(self) -> StepBasic_ProductDefinition: ...
	def ProductDefinitionRelationship(self) -> StepBasic_ProductDefinitionRelationship: ...
	def ProductDefinitionShape(self) -> StepRepr_ProductDefinitionShape: ...
	def RepresentationRelationship(self) -> StepRepr_RepresentationRelationship: ...
	def ShapeAspect(self) -> StepRepr_ShapeAspect: ...

class StepAP214_AutoDesignReferencingItem(StepData_SelectType):
	def __init__(self) -> None: ...
	def Approval(self) -> StepBasic_Approval: ...
	def CaseNum(self, ent: Standard_Transient) -> int: ...
	def DocumentRelationship(self) -> StepBasic_DocumentRelationship: ...
	def ExternallyDefinedRepresentation(self) -> StepRepr_ExternallyDefinedRepresentation: ...
	def MappedItem(self) -> StepRepr_MappedItem: ...
	def MaterialDesignation(self) -> StepRepr_MaterialDesignation: ...
	def PresentationArea(self) -> StepVisual_PresentationArea: ...
	def PresentationView(self) -> StepVisual_PresentationView: ...
	def ProductCategory(self) -> StepBasic_ProductCategory: ...
	def ProductDefinition(self) -> StepBasic_ProductDefinition: ...
	def ProductDefinitionRelationship(self) -> StepBasic_ProductDefinitionRelationship: ...
	def PropertyDefinition(self) -> StepRepr_PropertyDefinition: ...
	def Representation(self) -> StepRepr_Representation: ...
	def RepresentationRelationship(self) -> StepRepr_RepresentationRelationship: ...
	def ShapeAspect(self) -> StepRepr_ShapeAspect: ...

class StepAP214_AutoDesignSecurityClassificationAssignment(StepBasic_SecurityClassificationAssignment):
	def __init__(self) -> None: ...
	def Init(self, aAssignedSecurityClassification: StepBasic_SecurityClassification, aItems: StepBasic_HArray1OfApproval) -> None: ...
	def Items(self) -> StepBasic_HArray1OfApproval: ...
	def ItemsValue(self, num: int) -> StepBasic_Approval: ...
	def NbItems(self) -> int: ...
	def SetItems(self, aItems: StepBasic_HArray1OfApproval) -> None: ...

class StepAP214_Class(StepBasic_Group):
	def __init__(self) -> None: ...

class StepAP214_DocumentReferenceItem(StepData_SelectType):
	def __init__(self) -> None: ...
	def AppliedExternalIdentificationAssignment(self) -> StepAP214_AppliedExternalIdentificationAssignment: ...
	def Approval(self) -> StepBasic_Approval: ...
	def AssemblyComponentUsage(self) -> StepRepr_AssemblyComponentUsage: ...
	def CaseNum(self, ent: Standard_Transient) -> int: ...
	def CharacterizedObject(self) -> StepBasic_CharacterizedObject: ...
	def DescriptiveRepresentationItem(self) -> StepRepr_DescriptiveRepresentationItem: ...
	def DimensionalSize(self) -> StepShape_DimensionalSize: ...
	def ExternallyDefinedItem(self) -> StepBasic_ExternallyDefinedItem: ...
	def Group(self) -> StepBasic_Group: ...
	def GroupRelationship(self) -> StepBasic_GroupRelationship: ...
	def MaterialDesignation(self) -> StepRepr_MaterialDesignation: ...
	def MeasureRepresentationItem(self) -> StepRepr_MeasureRepresentationItem: ...
	def ProductCategory(self) -> StepBasic_ProductCategory: ...
	def ProductDefinition(self) -> StepBasic_ProductDefinition: ...
	def ProductDefinitionContext(self) -> StepBasic_ProductDefinitionContext: ...
	def ProductDefinitionRelationship(self) -> StepBasic_ProductDefinitionRelationship: ...
	def PropertyDefinition(self) -> StepRepr_PropertyDefinition: ...
	def Representation(self) -> StepRepr_Representation: ...
	def RepresentationItem(self) -> StepRepr_RepresentationItem: ...
	def ShapeAspect(self) -> StepRepr_ShapeAspect: ...
	def ShapeAspectRelationship(self) -> StepRepr_ShapeAspectRelationship: ...

class StepAP214_ExternalIdentificationItem(StepData_SelectType):
	def __init__(self) -> None: ...
	def AppliedOrganizationAssignment(self) -> StepAP214_AppliedOrganizationAssignment: ...
	def AppliedPersonAndOrganizationAssignment(self) -> StepAP214_AppliedPersonAndOrganizationAssignment: ...
	def Approval(self) -> StepBasic_Approval: ...
	def ApprovalStatus(self) -> StepBasic_ApprovalStatus: ...
	def CaseNum(self, ent: Standard_Transient) -> int: ...
	def DateAndTimeAssignment(self) -> StepBasic_DateAndTimeAssignment: ...
	def DateAssignment(self) -> StepBasic_DateAssignment: ...
	def DocumentFile(self) -> StepBasic_DocumentFile: ...
	def ExternalSource(self) -> StepBasic_ExternalSource: ...
	def ExternallyDefinedClass(self) -> StepAP214_ExternallyDefinedClass: ...
	def ExternallyDefinedGeneralProperty(self) -> StepAP214_ExternallyDefinedGeneralProperty: ...
	def OrganizationalAddress(self) -> StepBasic_OrganizationalAddress: ...
	def ProductDefinition(self) -> StepBasic_ProductDefinition: ...
	def SecurityClassification(self) -> StepBasic_SecurityClassification: ...
	def TrimmedCurve(self) -> StepGeom_TrimmedCurve: ...
	def VersionedActionRequest(self) -> StepBasic_VersionedActionRequest: ...

class StepAP214_ExternallyDefinedGeneralProperty(StepBasic_GeneralProperty):
	def __init__(self) -> None: ...
	def ExternallyDefinedItem(self) -> StepBasic_ExternallyDefinedItem: ...
	def Init(self, aGeneralProperty_Id: TCollection_HAsciiString, aGeneralProperty_Name: TCollection_HAsciiString, hasGeneralProperty_Description: bool, aGeneralProperty_Description: TCollection_HAsciiString, aExternallyDefinedItem_ItemId: StepBasic_SourceItem, aExternallyDefinedItem_Source: StepBasic_ExternalSource) -> None: ...
	def SetExternallyDefinedItem(self, ExternallyDefinedItem: StepBasic_ExternallyDefinedItem) -> None: ...

class StepAP214_GroupItem(StepData_SelectType):
	def __init__(self) -> None: ...
	def CaseNum(self, ent: Standard_Transient) -> int: ...
	def GeometricRepresentationItem(self) -> StepGeom_GeometricRepresentationItem: ...
	def GroupRelationship(self) -> StepBasic_GroupRelationship: ...
	def MappedItem(self) -> StepRepr_MappedItem: ...
	def ProductDefinition(self) -> StepBasic_ProductDefinition: ...
	def ProductDefinitionFormation(self) -> StepBasic_ProductDefinitionFormation: ...
	def PropertyDefinitionRepresentation(self) -> StepRepr_PropertyDefinitionRepresentation: ...
	def Representation(self) -> StepRepr_Representation: ...
	def RepresentationItem(self) -> StepRepr_RepresentationItem: ...
	def RepresentationRelationshipWithTransformation(self) -> StepRepr_RepresentationRelationshipWithTransformation: ...
	def ShapeAspect(self) -> StepRepr_ShapeAspect: ...
	def ShapeAspectRelationship(self) -> StepRepr_ShapeAspectRelationship: ...
	def ShapeRepresentationRelationship(self) -> StepRepr_ShapeRepresentationRelationship: ...
	def StyledItem(self) -> StepVisual_StyledItem: ...
	def TopologicalRepresentationItem(self) -> StepShape_TopologicalRepresentationItem: ...

class StepAP214_PresentedItemSelect(StepData_SelectType):
	def __init__(self) -> None: ...
	def CaseNum(self, ent: Standard_Transient) -> int: ...
	def ProductDefinition(self) -> StepBasic_ProductDefinition: ...
	def ProductDefinitionRelationship(self) -> StepBasic_ProductDefinitionRelationship: ...

class StepAP214_Protocol(StepData_Protocol):
	def __init__(self) -> None: ...
	def NbResources(self) -> int: ...
	def Resource(self, num: int) -> Interface_Protocol: ...
	def SchemaName(self) -> str: ...
	def TypeNumber(self, atype: Standard_Type) -> int: ...

class StepAP214_RepItemGroup(StepBasic_Group):
	def __init__(self) -> None: ...
	def Init(self, aGroup_Name: TCollection_HAsciiString, hasGroup_Description: bool, aGroup_Description: TCollection_HAsciiString, aRepresentationItem_Name: TCollection_HAsciiString) -> None: ...
	def RepresentationItem(self) -> StepRepr_RepresentationItem: ...
	def SetRepresentationItem(self, RepresentationItem: StepRepr_RepresentationItem) -> None: ...

class StepAP214_AutoDesignOrganizationItem(StepAP214_AutoDesignGeneralOrgItem):
	def __init__(self) -> None: ...
	def CaseNum(self, ent: Standard_Transient) -> int: ...
	def Document(self) -> StepBasic_Document: ...
	def PhysicallyModeledProductDefinition(self) -> StepBasic_PhysicallyModeledProductDefinition: ...

class StepAP214_DateAndTimeItem(StepAP214_ApprovalItem):
	def __init__(self) -> None: ...
	def AppliedOrganizationAssignment(self) -> StepAP214_AppliedOrganizationAssignment: ...
	def AppliedPersonAndOrganizationAssignment(self) -> StepAP214_AppliedPersonAndOrganizationAssignment: ...
	def ApprovalPersonOrganization(self) -> StepBasic_ApprovalPersonOrganization: ...
	def CaseNum(self, ent: Standard_Transient) -> int: ...

class StepAP214_DateItem(StepAP214_ApprovalItem):
	def __init__(self) -> None: ...
	def AppliedOrganizationAssignment(self) -> StepAP214_AppliedOrganizationAssignment: ...
	def AppliedPersonAndOrganizationAssignment(self) -> StepAP214_AppliedPersonAndOrganizationAssignment: ...
	def AppliedSecurityClassificationAssignment(self) -> StepAP214_AppliedSecurityClassificationAssignment: ...
	def ApprovalPersonOrganization(self) -> StepBasic_ApprovalPersonOrganization: ...
	def CaseNum(self, ent: Standard_Transient) -> int: ...

class StepAP214_ExternallyDefinedClass(StepAP214_Class):
	def __init__(self) -> None: ...
	def ExternallyDefinedItem(self) -> StepBasic_ExternallyDefinedItem: ...
	def Init(self, aGroup_Name: TCollection_HAsciiString, hasGroup_Description: bool, aGroup_Description: TCollection_HAsciiString, aExternallyDefinedItem_ItemId: StepBasic_SourceItem, aExternallyDefinedItem_Source: StepBasic_ExternalSource) -> None: ...
	def SetExternallyDefinedItem(self, ExternallyDefinedItem: StepBasic_ExternallyDefinedItem) -> None: ...

class StepAP214_OrganizationItem(StepAP214_ApprovalItem):
	def __init__(self) -> None: ...
	def AppliedOrganizationAssignment(self) -> StepAP214_AppliedOrganizationAssignment: ...
	def AppliedSecurityClassificationAssignment(self) -> StepAP214_AppliedSecurityClassificationAssignment: ...
	def Approval(self) -> StepBasic_Approval: ...
	def CaseNum(self, ent: Standard_Transient) -> int: ...

class StepAP214_PersonAndOrganizationItem(StepAP214_ApprovalItem):
	def __init__(self) -> None: ...
	def AppliedOrganizationAssignment(self) -> StepAP214_AppliedOrganizationAssignment: ...
	def AppliedSecurityClassificationAssignment(self) -> StepAP214_AppliedSecurityClassificationAssignment: ...
	def Approval(self) -> StepBasic_Approval: ...
	def CaseNum(self, ent: Standard_Transient) -> int: ...

class StepAP214_SecurityClassificationItem(StepAP214_ApprovalItem):
	def __init__(self) -> None: ...
	def Action(self) -> StepBasic_Action: ...
	def AssemblyComponentUsage(self) -> StepRepr_AssemblyComponentUsage: ...
	def CaseNum(self, ent: Standard_Transient) -> int: ...
	def ConfigurationDesign(self) -> StepRepr_ConfigurationDesign: ...
	def ConfigurationEffectivity(self) -> StepRepr_ConfigurationEffectivity: ...
	def DraughtingModel(self) -> StepVisual_DraughtingModel: ...
	def GeneralProperty(self) -> StepBasic_GeneralProperty: ...
	def MakeFromUsageOption(self) -> StepRepr_MakeFromUsageOption: ...
	def ProductConcept(self) -> StepRepr_ProductConcept: ...
	def ProductDefinitionUsage(self) -> StepRepr_ProductDefinitionUsage: ...
	def VersionedActionRequest(self) -> StepBasic_VersionedActionRequest: ...

# harray1 classes

class StepAP214_HArray1OfDateItem(StepAP214_Array1OfDateItem, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> StepAP214_Array1OfDateItem: ...


class StepAP214_HArray1OfSecurityClassificationItem(StepAP214_Array1OfSecurityClassificationItem, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> StepAP214_Array1OfSecurityClassificationItem: ...


class StepAP214_HArray1OfExternalIdentificationItem(StepAP214_Array1OfExternalIdentificationItem, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> StepAP214_Array1OfExternalIdentificationItem: ...


class StepAP214_HArray1OfAutoDesignDatedItem(StepAP214_Array1OfAutoDesignDatedItem, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> StepAP214_Array1OfAutoDesignDatedItem: ...


class StepAP214_HArray1OfPersonAndOrganizationItem(StepAP214_Array1OfPersonAndOrganizationItem, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> StepAP214_Array1OfPersonAndOrganizationItem: ...


class StepAP214_HArray1OfAutoDesignDateAndPersonItem(StepAP214_Array1OfAutoDesignDateAndPersonItem, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> StepAP214_Array1OfAutoDesignDateAndPersonItem: ...


class StepAP214_HArray1OfAutoDesignGroupedItem(StepAP214_Array1OfAutoDesignGroupedItem, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> StepAP214_Array1OfAutoDesignGroupedItem: ...


class StepAP214_HArray1OfPresentedItemSelect(StepAP214_Array1OfPresentedItemSelect, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> StepAP214_Array1OfPresentedItemSelect: ...


class StepAP214_HArray1OfAutoDesignGeneralOrgItem(StepAP214_Array1OfAutoDesignGeneralOrgItem, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> StepAP214_Array1OfAutoDesignGeneralOrgItem: ...


class StepAP214_HArray1OfAutoDesignDateAndTimeItem(StepAP214_Array1OfAutoDesignDateAndTimeItem, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> StepAP214_Array1OfAutoDesignDateAndTimeItem: ...


class StepAP214_HArray1OfAutoDesignPresentedItemSelect(StepAP214_Array1OfAutoDesignPresentedItemSelect, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> StepAP214_Array1OfAutoDesignPresentedItemSelect: ...


class StepAP214_HArray1OfAutoDesignReferencingItem(StepAP214_Array1OfAutoDesignReferencingItem, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> StepAP214_Array1OfAutoDesignReferencingItem: ...


class StepAP214_HArray1OfDocumentReferenceItem(StepAP214_Array1OfDocumentReferenceItem, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> StepAP214_Array1OfDocumentReferenceItem: ...


class StepAP214_HArray1OfOrganizationItem(StepAP214_Array1OfOrganizationItem, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> StepAP214_Array1OfOrganizationItem: ...


class StepAP214_HArray1OfApprovalItem(StepAP214_Array1OfApprovalItem, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> StepAP214_Array1OfApprovalItem: ...


class StepAP214_HArray1OfGroupItem(StepAP214_Array1OfGroupItem, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> StepAP214_Array1OfGroupItem: ...


class StepAP214_HArray1OfDateAndTimeItem(StepAP214_Array1OfDateAndTimeItem, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> StepAP214_Array1OfDateAndTimeItem: ...

# harray2 classes
# hsequence classes

stepap214_Protocol = stepap214.Protocol



from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *

#the following typedef cannot be wrapped as is
Storage_PType = NewType('Storage_PType', Any)
Storage_Position = NewType('Storage_Position', long)

class Storage_ArrayOfCallBack:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> False: ...
    def __setitem__(self, index: int, value: False) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[False]: ...
    def next(self) -> False: ...
    __next__ = next
    def Init(self, theValue: False) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class Storage_ArrayOfSchema:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> False: ...
    def __setitem__(self, index: int, value: False) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[False]: ...
    def next(self) -> False: ...
    __next__ = next
    def Init(self, theValue: False) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class Storage_SeqOfRoot:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Length(self) -> int: ...
    def Append(self, theItem: False) -> False: ...
    def Prepend(self, theItem: False) -> False: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class Storage_SolveMode(IntEnum):
	Storage_AddSolve: int = ...
	Storage_WriteSolve: int = ...
	Storage_ReadSolve: int = ...
Storage_AddSolve = Storage_SolveMode.Storage_AddSolve
Storage_WriteSolve = Storage_SolveMode.Storage_WriteSolve
Storage_ReadSolve = Storage_SolveMode.Storage_ReadSolve

class Storage_Error(IntEnum):
	Storage_VSOk: int = ...
	Storage_VSOpenError: int = ...
	Storage_VSModeError: int = ...
	Storage_VSCloseError: int = ...
	Storage_VSAlreadyOpen: int = ...
	Storage_VSNotOpen: int = ...
	Storage_VSSectionNotFound: int = ...
	Storage_VSWriteError: int = ...
	Storage_VSFormatError: int = ...
	Storage_VSUnknownType: int = ...
	Storage_VSTypeMismatch: int = ...
	Storage_VSInternalError: int = ...
	Storage_VSExtCharParityError: int = ...
	Storage_VSWrongFileDriver: int = ...
Storage_VSOk = Storage_Error.Storage_VSOk
Storage_VSOpenError = Storage_Error.Storage_VSOpenError
Storage_VSModeError = Storage_Error.Storage_VSModeError
Storage_VSCloseError = Storage_Error.Storage_VSCloseError
Storage_VSAlreadyOpen = Storage_Error.Storage_VSAlreadyOpen
Storage_VSNotOpen = Storage_Error.Storage_VSNotOpen
Storage_VSSectionNotFound = Storage_Error.Storage_VSSectionNotFound
Storage_VSWriteError = Storage_Error.Storage_VSWriteError
Storage_VSFormatError = Storage_Error.Storage_VSFormatError
Storage_VSUnknownType = Storage_Error.Storage_VSUnknownType
Storage_VSTypeMismatch = Storage_Error.Storage_VSTypeMismatch
Storage_VSInternalError = Storage_Error.Storage_VSInternalError
Storage_VSExtCharParityError = Storage_Error.Storage_VSExtCharParityError
Storage_VSWrongFileDriver = Storage_Error.Storage_VSWrongFileDriver

class Storage_OpenMode(IntEnum):
	Storage_VSNone: int = ...
	Storage_VSRead: int = ...
	Storage_VSWrite: int = ...
	Storage_VSReadWrite: int = ...
Storage_VSNone = Storage_OpenMode.Storage_VSNone
Storage_VSRead = Storage_OpenMode.Storage_VSRead
Storage_VSWrite = Storage_OpenMode.Storage_VSWrite
Storage_VSReadWrite = Storage_OpenMode.Storage_VSReadWrite

#classnotwrapped
class Storage_Bucket: ...

#classnotwrapped
class Storage_BucketOfPersistent: ...

#classnotwrapped
class Storage_BucketIterator: ...

#classnotwrapped
class Storage_RootData: ...

#classnotwrapped
class Storage_TypeData: ...

#classnotwrapped
class Storage_Root: ...

#classnotwrapped
class Storage_Schema: ...

#classnotwrapped
class Storage_DefaultCallBack: ...

#classnotwrapped
class Storage_TypedCallBack: ...

#classnotwrapped
class Storage_CallBack: ...

#classnotwrapped
class Storage_HeaderData: ...

#classnotwrapped
class Storage_BaseDriver: ...

#classnotwrapped
class Storage_InternalData: ...

#classnotwrapped
class Storage_Data: ...

#classnotwrapped
class Storage: ...

# harray1 classes

class Storage_HArrayOfSchema(Storage_ArrayOfSchema, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> Storage_ArrayOfSchema: ...


class Storage_HPArray(Storage_PArray, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> Storage_PArray: ...


class Storage_HArrayOfCallBack(Storage_ArrayOfCallBack, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> Storage_ArrayOfCallBack: ...

# harray2 classes
# hsequence classes

class Storage_HSeqOfRoot(Storage_SeqOfRoot, Standard_Transient):
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, other: Storage_SeqOfRoot) -> None: ...
    def Sequence(self) -> Storage_SeqOfRoot: ...
    def Append(self, theSequence: Storage_SeqOfRoot) -> None: ...


